; -*- Scheme -*-

(module sx-canvas mzscheme

  (require (lib "class.ss") 
           (lib "mred.ss" "mred"))
  
  (provide sx-image-canvas-background-color
           sx-image-canvas-background-draw
           sx-image-canvas-bitmap-set!
           sx-image-canvas-bitmap-draw
           sx-image-canvas
  )
  
  (define image-canvas%
    (class canvas%

      (define bg-r 255)
      (define bg-g 255)
      (define bg-b 255)
      (define image #f)
      
      (define/public (background-color r g b)
        (set! bg-r r)
        (set! bg-g g)
        (set! bg-b b)
        (queue-callback (lambda x (send this on-paint)) #t) 
      )
      
      (define/public (get-bg-r)
        bg-r
      )
      
      (define/public (get-bg-g)
        bg-g
      )
      
      (define/public (get-bg-b)
        bg-b
      )
      
      (define/public (image-set! filename)
        (let
          ((bitmap (make-object bitmap% filename))
          )
          (if (send bitmap ok?)
            (set! image bitmap)
          )
          (queue-callback (lambda x (send this on-paint)) #t)
        )
      )
      
      (define/public (image-get)
        image
      )
      
      (super-new)
    )
  )
  
  (define (sx-image-canvas-background-color image r g b)
    (send image background-color r g b)
  )
  
  (define (sx-image-canvas-bitmap-set! image filename)
    (send image image-set! filename)
  )
  
  (define (sx-image-canvas-background-draw canvas)
    (let
      ((dc (send canvas get-dc)))
      (send dc set-background 
            (make-object color% 
              (send canvas get-bg-r)
              (send canvas get-bg-g)
              (send canvas get-bg-b))
      )
      (send dc clear)
    )
  )
  
  
  (define (sx-image-canvas-bitmap-draw canvas)
    (if (and (send canvas image-get)
             (send (send canvas image-get) ok?))
      (let
        ((dc (send canvas get-dc)))
        (send dc draw-bitmap (send canvas image-get) 0 0)
      )
    )
  )
  

  (define (sx-image-canvas parent width height callback)
    (new image-canvas%
         (parent parent)
         (min-width width)
         (min-height height)
         (stretchable-width #f)
         (stretchable-height #f)
         (horiz-margin 2)
         (vert-margin 2)
         (paint-callback (lambda (canvas dc) (callback)))
    )
  )
  
) ;end of module


