; -*- Scheme -*-

; This file contains the definition of the text entry widget
(module sx-entry
        mzscheme

(require (lib "class.ss") 
         (lib "mred.ss" "mred")
)

(provide sx-entry-new
         sx-entry?
         sx-entry-event-enter?
         sx-entry-event?
         sx-entry-text-set! 
         sx-entry-text-append!
         sx-entry-text-get
         sx-entry-label-set!
         sx-entry-focus 
         sx-entry-enable-set!
         sx-entry-send-key
         sx-entry-stretch-x-set!
         sx-entry-min-width-set!
         sx-entry-min-height-set!
)


(define sx-text%
  (class text-field% ()
    (super-instantiate ())
    (let*
      ( (editor (send this get-editor))
        (keymap (send editor get-keymap))
      )
      (send keymap add-function "all-text-select"
        (lambda (edit event) (send edit select-all)))
      (send keymap map-function "leftbuttondouble" "all-text-select")

      ; history of entries
      (send keymap add-function "prev-entry"
        (lambda (edit event) (send editor undo)))
      (send keymap add-function "next-entry"
        (lambda (edit event) (send editor redo)))
      (send keymap map-function "up"     "prev-entry")
      (send keymap map-function "down"   "next-entry")
    )
    this
  )
)
(define (sx-entry-new parent label callback init)
  (new sx-text%
       (label label)
       (parent parent)
       (callback callback)
       (init-value init)
  )
)

(define (sx-entry? widget)
  (is-a? widget sx-text%)
)

(define (sx-entry-event-enter? window event)
  (eq? (send event get-event-type) 'text-field-enter)
)

(define (sx-entry-event? window event)
  (eq? (send event get-event-type) 'text-field)
)

(define (sx-entry-text-set! entry text)
  (send entry set-value text)
)

(define (sx-entry-text-append! entry text)
  (send entry set-value (string-append (send entry get-value) text))
)

(define (sx-entry-text-get entry)
  (send entry get-value)
)

(define (sx-entry-label-set! entry label)
  (send entry set-label label)
)

(define (sx-entry-focus entry)
  (send entry focus)
)

(define (sx-entry-enable-set! entry enable?)
  (send entry enable enable?)
)

(define (sx-entry-send-key entry key)
  (queue-callback 
      (lambda x 
        (send (send entry get-editor)
              on-char
              (new key-event% (key-code key))
        )
      )
      #t
  )
)

(define (sx-entry-stretch-x-set! entry enable?)
  (send entry stretchable-width enable?)
)

(define (sx-entry-min-width-set! entry width)
  (send entry min-width width)
)

(define (sx-entry-min-height-set! entry height)
  (send entry min-height height)
)


) ; end of module



